# Batch Image Processing


A Python Package for Fast Parallel Processing of Images. It's Simple, easy and extremely fast since it uses, all the cores in your CPU. batchimage uses opencv-python as its main dependency and few python core modules.

![PyPI - Python Version](https://img.shields.io/pypi/pyversions/batchimage?style=for-the-badge)

### Python Package Index Badges

[![PyPI](https://img.shields.io/pypi/v/batchimage?style=for-the-badge&color=gree&logo=pypi)](https://pypi.org/project/batchimage/)
![PyPI - Downloads](https://img.shields.io/pypi/dm/batchimage?label=Downloads&style=for-the-badge)
![PyPI - Status](https://img.shields.io/pypi/status/batchimage?label=Status&style=for-the-badge)
![PyPI - Format](https://img.shields.io/pypi/format/batchimage?label=Format&style=for-the-badge)


### Github Badges

![GitHub last commit](https://img.shields.io/github/last-commit/insumanth/batchimage?style=for-the-badge)
![GitHub commit activity](https://img.shields.io/github/commit-activity/y/insumanth/batchimage?style=for-the-badge)
![GitHub code size in bytes](https://img.shields.io/github/languages/code-size/insumanth/batchimage?style=for-the-badge)
![Lines of code](https://img.shields.io/tokei/lines/github/insumanth/batchimage?style=for-the-badge)



------------------
## Python Package Index Install 

```
pip install batchimage
```

### Note :
This is a pre-alpha version of the package, the api will change without any notice. Please use this package with caution.

<!--
Table
-->

### Timeline for Development

| Present |                              September 2022                               |                              October 2022                               | November'22                                                                  |
|:---:|:-------------------------------------------------------------------------:|:-----------------------------------------------------------------------:|------------------------------------------------------------------------------|
| ![Pre-Alpha](https://img.shields.io/badge/0-PRE--ALPHA-red?style=for-the-badge) | ![Alpha](https://img.shields.io/badge/1-ALPHA-orange?style=for-the-badge) | ![Beta](https://img.shields.io/badge/2-BETA-yellow?style=for-the-badge) | ![Release](https://img.shields.io/badge/3-RELEASE-green?style=for-the-badge) |



-----------------
![Made With Python](https://forthebadge.com/images/badges/made-with-python.svg)
![forthebadge](https://forthebadge.com/images/badges/built-with-love.svg)

<!--
<img src="https://forthebadge.com/images/badges/works-on-my-machine.svg" alt="works-on-my-machine" width="500" height="100">
-->
